==> nextcloud-31.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/zh_TW.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "無效的聯邦雲端 ID",
    "Server to server sharing is not enabled on this server" : "伺服器對伺服器共享在這台伺服器上面並未啟用",
    "Couldn't establish a federated share." : "無法建立聯邦分享。",
    "Couldn't establish a federated share, maybe the password was wrong." : "無法建立聯邦分享，可能是密碼錯誤。",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "已傳送聯邦分享請求，您將會收到邀請。請檢查您的通知。",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "無法建立聯邦分享，看來是聯邦的伺服器太舊了（Nextcloud <= 9）。",
    "It is not allowed to send federated group shares from this server." : "不允許從此伺服器傳送聯邦群組分享。",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "分享 %1$s 失敗，因為此項目已與帳號 %2$s 分享",
    "Not allowed to create a federated share to the same account" : "不允許與同一個帳號建立聯邦分享",
    "Federated shares require read permissions" : "聯邦分享需要讀取權",
    "File is already shared with %s" : "檔案已與 %s 分享",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "分享 %1$s 失敗，找不到 %2$s，可能伺服器目前無法存取，或使用了自行簽署的憑證。",
    "Could not find share" : "找不到分享",
    "Federated sharing" : "聯邦分享",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "您收到了來自 {user}（代表 {behalf}）的遠端分享 {share}",
    "You received {share} as a remote share from {user}" : "您收到來自 {user} 的遠端分享 {share}",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "Federated Cloud Sharing" : "聯邦雲端分享",
    "Sharing" : "分享",
    "Federated file sharing" : "聯邦檔案分享",
    "Provide federated file sharing across servers" : "提供跨伺服器的聯邦檔案分享",
    "Unable to update federated files sharing config" : "無法更新聯邦檔案分享組態設定",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "調整人們如何在伺服器間分享。這也包含此伺服器上使用者間的分享，如果他們使用聯盟式分享的話。",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "允許此伺服器上的使用者傳送分享到其他伺服器（此選項也允許 WebDAV 存取公開分享）",
    "Allow people on this server to receive shares from other servers" : "允許此伺服器上的使用者接收來自其他伺服器的分享",
    "Allow people on this server to send shares to groups on other servers" : "允許此伺服器上的使用者傳送分享在其他伺服器上的群組",
    "Allow people on this server to receive group shares from other servers" : "允許此伺服器上的使用者接收來自其他伺服器的群組分享",
    "The lookup server is only available for global scale." : "查詢伺服器僅適用於全球規模。",
    "Search global and public address book for people" : "搜尋全域與公開通訊錄中的使用者",
    "Allow people to publish their data to a global and public address book" : "允許使用者將其資料發佈到全域且公開的通訊錄",
    "Trusted federation" : "信任的聯邦",
    "Automatically accept shares from trusted federated accounts and groups by default" : "預設自動接受來自受信任的聯邦帳號與群組的分享",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "透過我的 #Nextcloud 聯邦雲端 ID 與我分享，請見 {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "透過我的 #Nextcloud 聯邦雲端 ID 與我分享",
    "Cloud ID copied to the clipboard" : "雲端 ID 已複製到剪貼簿",
    "Copy to clipboard" : "複製到剪貼簿",
    "Clipboard not available. Please copy the cloud ID manually." : "無法使用剪貼簿。請手動複製雲端 ID。",
    "Copied!" : "已複製！",
    "Federated Cloud" : "聯邦雲端",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "您可以與任何使用 Nextcloud 伺服器，或其他相容於 Open Cloud Mesh (OCM) 的伺服器與服務分享！只要把他們的聯邦雲端 ID 放在分享對話方塊中。ID 看起來會像 person@cloud.example.com",
    "Your Federated Cloud ID" : "您的雲端聯邦 ID",
    "Share it so your friends can share files with you:" : "分享 ID，然後您的朋友就能透過它與您分享檔案：",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X（前身為 Twitter）",
    "formerly Twitter" : "前身為 Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "新增至您的網站",
    "Share with me via Nextcloud" : "透過 Nextcloud 與我分享",
    "HTML Code:" : "HTML 程式碼：",
    "Cancel" : "取消",
    "Add remote share" : "新增遠端分享",
    "Remote share" : "遠端分享",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "是否要新增來自 {owner}@{remote} 的遠端分享 {name} ？",
    "Remote share password" : "遠端分享密碼",
    "Incoming share could not be processed" : "無法處理收到的分享",
    "Clipboard is not available" : "剪貼簿無法使用",
    "Your Federated Cloud ID:" : "您的聯邦雲端 ID：",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/zh_TW.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "無效的聯邦雲端 ID",
    "Server to server sharing is not enabled on this server" : "伺服器對伺服器共享在這台伺服器上面並未啟用",
    "Couldn't establish a federated share." : "無法建立聯邦分享。",
    "Couldn't establish a federated share, maybe the password was wrong." : "無法建立聯邦分享，可能是密碼錯誤。",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "已傳送聯邦分享請求，您將會收到邀請。請檢查您的通知。",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "無法建立聯邦分享，看來是聯邦的伺服器太舊了（Nextcloud <= 9）。",
    "It is not allowed to send federated group shares from this server." : "不允許從此伺服器傳送聯邦群組分享。",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "分享 %1$s 失敗，因為此項目已與帳號 %2$s 分享",
    "Not allowed to create a federated share to the same account" : "不允許與同一個帳號建立聯邦分享",
    "Federated shares require read permissions" : "聯邦分享需要讀取權",
    "File is already shared with %s" : "檔案已與 %s 分享",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "分享 %1$s 失敗，找不到 %2$s，可能伺服器目前無法存取，或使用了自行簽署的憑證。",
    "Could not find share" : "找不到分享",
    "Federated sharing" : "聯邦分享",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "您收到了來自 {user}（代表 {behalf}）的遠端分享 {share}",
    "You received {share} as a remote share from {user}" : "您收到來自 {user} 的遠端分享 {share}",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "Federated Cloud Sharing" : "聯邦雲端分享",
    "Sharing" : "分享",
    "Federated file sharing" : "聯邦檔案分享",
    "Provide federated file sharing across servers" : "提供跨伺服器的聯邦檔案分享",
    "Confirm data upload to lookup server" : "確認資料上傳至查詢伺服器",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "啟用後，所有範圍能見度設定為「公開」的帳號屬性（例如電子郵件地址）將會自動同步並傳輸到外部系統，並在公開全域通訊錄中提供。",
    "Disable upload" : "停用上傳",
    "Enable data upload" : "啟用資料上傳",
    "Confirm querying lookup server" : "確認詢問查詢伺服器",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "啟用後，建立分享時的搜尋輸入將會被傳送至提供公開全域通訊錄的外部系統。",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "這是用來擷取聯盟雲端 ID，讓聯盟分享更簡單。",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "此外，使用者的電子郵件地址可能會被傳送至該系統以進行驗證。",
    "Disable querying" : "停用詢問",
    "Enable querying" : "啟用詢問",
    "Unable to update federated files sharing config" : "無法更新聯邦檔案分享組態設定",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "調整人們如何在伺服器間分享。這也包含此伺服器上使用者間的分享，如果他們使用聯盟式分享的話。",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "允許此伺服器上的使用者傳送分享到其他伺服器（此選項也允許 WebDAV 存取公開分享）",
    "Allow people on this server to receive shares from other servers" : "允許此伺服器上的使用者接收來自其他伺服器的分享",
    "Allow people on this server to send shares to groups on other servers" : "允許此伺服器上的使用者傳送分享在其他伺服器上的群組",
    "Allow people on this server to receive group shares from other servers" : "允許此伺服器上的使用者接收來自其他伺服器的群組分享",
    "The lookup server is only available for global scale." : "查詢伺服器僅適用於全球規模。",
    "Search global and public address book for people" : "搜尋全域與公開通訊錄中的使用者",
    "Allow people to publish their data to a global and public address book" : "允許使用者將其資料發佈到全域且公開的通訊錄",
    "Trusted federation" : "信任的聯邦",
    "Automatically accept shares from trusted federated accounts and groups by default" : "預設自動接受來自受信任的聯邦帳號與群組的分享",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "透過我的 #Nextcloud 聯邦雲端 ID 與我分享，請見 {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "透過我的 #Nextcloud 聯邦雲端 ID 與我分享",
    "Share with me via Nextcloud" : "透過 Nextcloud 與我分享",
    "Cloud ID copied" : "已複製雲端 ID",
    "Copy" : "複製",
    "Clipboard not available. Please copy the cloud ID manually." : "無法使用剪貼簿。請手動複製雲端 ID。",
    "Copied!" : "已複製！",
    "Federated Cloud" : "聯邦雲端",
    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "您可以與任何使用 {productName} 伺服器，或其他相容於 Open Cloud Mesh (OCM) 的伺服器與服務分享！只要把他們的聯邦雲端 ID 放在分享對話方塊中。ID 看起來會像 person@cloud.example.com",
    "Your Federated Cloud ID" : "您的雲端聯邦 ID",
    "Share it so your friends can share files with you:" : "分享 ID，然後您的朋友就能透過它與您分享檔案：",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X（前身為 Twitter）",
    "formerly Twitter" : "前身為 Twitter",
    "Mastodon" : "Mastodon",
    "Bluesky" : "Bluesky",
    "Add to your website" : "新增至您的網站",
    "Share with me via {productName}" : "透過 {productName} 與我分享",
    "HTML Code:" : "HTML 程式碼：",
    "Cancel" : "取消",
    "Add remote share" : "新增遠端分享",
    "Remote share" : "遠端分享",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "是否要新增來自 {owner}@{remote} 的遠端分享 {name} ？",
    "Remote share password" : "遠端分享密碼",
    "Incoming share could not be processed" : "無法處理收到的分享",
    "Cloud ID copied to the clipboard" : "雲端 ID 已複製到剪貼簿",
    "Copy to clipboard" : "複製到剪貼簿",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "您可以與任何使用 Nextcloud 伺服器，或其他相容於 Open Cloud Mesh (OCM) 的伺服器與服務分享！只要把他們的聯邦雲端 ID 放在分享對話方塊中。ID 看起來會像 person@cloud.example.com"
},
"nplurals=1; plural=0;");
